@@ -83,7 +83,7 @@ def test_all_deps_hidden(db, form, document_factory, form_question_factory):
         }
     )
     assert qj.is_hidden(q2)
-    assert not qj.is_required(q2)
+    assert not qj.is_required(structure.Field(document, document.form, q2))
 
 
 @pytest.mark.parametrize("fq_is_hidden", ["true", "false"])
@@ -347,3 +347,54 @@ def test_answer_transform_on_hidden_question_types(
     )
 
     assert qj.is_hidden(questions["form_question"])
+
+
+@pytest.mark.parametrize(
+    "jexl_field,expr",
+    [
+        ("is_required", "('column'|answer == 5)"),
+        ("is_hidden", "('column'|answer > 10)"),
+    ],
+)
+def test_answer_transform_in_tables(
+    info,
+    form_and_document,
+    form_question_factory,
+    jexl_field,
+    expr,
+    answer_document_factory,
+):
+
+    form, document, questions, answers = form_and_document(
+        use_table=True, use_subform=False
+    )
+
+    table_question = questions["table_question"]
+
+    col2_question = form_question_factory(
+        **{
+            "form": table_question.row_form,
+            "question__slug": "column2",
+            "question__is_hidden": "false",
+            "question__is_required": "true",
+            # this overrwrites above "default values"
+            f"question__{jexl_field}": expr,
+        }
+    ).question
+    assert getattr(col2_question, jexl_field) == expr
+
+    table_answer = answers["table_question"]
+
+    row2_doc = answer_document_factory(
+        answer=table_answer, document__form=table_question.row_form, sort=10
+    ).document
+
+    # Second row has an answer that triggers the transform and implies a validation error.
+    # This will wrongfully succeed if the answer value comes from the wrong row
+    row2_doc.answers.create(question_id="column", value=5)
+
+    validator = validators.DocumentValidator()
+    # we expect this to fail, as in the second row, the 'column' answer is 5,
+    # so 'column2' should be required
+    with pytest.raises(validators.CustomValidationError):
+        validator.validate(document, info)
