@@ -1,5 +1,5 @@
+from django.core.exceptions import ValidationError
 from django.db import transaction
-from django.utils import timezone
 from rest_framework import exceptions
 from rest_framework.serializers import CharField, ListField
 from simple_history.utils import bulk_create_with_history
@@ -8,68 +8,10 @@ from caluma.caluma_core.events import SendEventSerializerMixin
 
 from ..caluma_core import serializers
 from ..caluma_form.models import Document, Form
-from . import events, models, validators
+from . import domain_logic, events, models, utils
 from .jexl import FlowJexl, GroupJexl
 
 
-def get_group_jexl_structure(work_item_created_by_group, case, prev_work_item=None):
-    return {
-        "case": {"created_by_group": case.created_by_group},
-        "work_item": {"created_by_group": work_item_created_by_group},
-        "prev_work_item": {
-            "controlling_groups": prev_work_item.controlling_groups
-            if prev_work_item
-            else None
-        },
-    }
-
-
-def get_jexl_groups(jexl, case, work_item_created_by_group, prev_work_item=None):
-    context = get_group_jexl_structure(work_item_created_by_group, case, prev_work_item)
-    if jexl:
-        return GroupJexl(validation_context=context).evaluate(jexl)
-    return []
-
-
-def bulk_create_work_items(tasks, case, user, prev_work_item=None):
-    work_items = []
-    for task in tasks:
-        controlling_groups = get_jexl_groups(
-            task.control_groups,
-            case,
-            user.group,
-            prev_work_item if prev_work_item else None,
-        )
-        addressed_groups = [
-            get_jexl_groups(
-                task.address_groups,
-                case,
-                user.group,
-                prev_work_item if prev_work_item else None,
-            )
-        ]
-        if task.is_multiple_instance:
-            addressed_groups = [[x] for x in addressed_groups[0]]
-
-        for groups in addressed_groups:
-            work_items.append(
-                models.WorkItem(
-                    addressed_groups=groups,
-                    controlling_groups=controlling_groups,
-                    task_id=task.pk,
-                    deadline=task.calculate_deadline(),
-                    document=Document.objects.create_document_for_task(task, user),
-                    case=case,
-                    status=models.WorkItem.STATUS_READY,
-                    created_by_user=user.username,
-                    created_by_group=user.group,
-                )
-            )
-
-    bulk_create_with_history(work_items, models.WorkItem)
-    return work_items
-
-
 class FlowJexlField(serializers.JexlField):
     def __init__(self, **kwargs):
         super().__init__(FlowJexl(), **kwargs)
@@ -128,7 +70,9 @@ class AddWorkflowFlowSerializer(serializers.ModelSerializer):
     def update(self, instance, validated_data):
         user = self.context["request"].user
         tasks = validated_data["tasks"]
-        models.Flow.objects.filter(task_flows__task__in=tasks).delete()
+        models.Flow.objects.filter(
+            task_flows__workflow=instance, task_flows__task__in=tasks
+        ).delete()
         flow = models.Flow.objects.create(
             next=validated_data["next"],
             created_by_user=user.username,
@@ -229,56 +173,24 @@ class CaseSerializer(SendEventSerializerMixin, serializers.ModelSerializer):
     )
 
     def validate(self, data):
-        form = data.get("form")
-        workflow = data["workflow"]
-
-        if form:
-            if (
-                not workflow.allow_all_forms
-                and not workflow.allow_forms.filter(pk=form.pk).exists()
-            ):
-                raise exceptions.ValidationError(
-                    f"Workflow {workflow.pk} does not allow to start case with form {form.pk}"
-                )
+        try:
+            data = domain_logic.StartCaseLogic.validate_for_start(data)
+        except ValidationError as e:
+            raise exceptions.ValidationError(str(e))
 
         return super().validate(data)
 
     @transaction.atomic
     def create(self, validated_data):
         user = self.context["request"].user
-        parent_work_item = validated_data.get("parent_work_item")
-        validated_data["status"] = models.Case.STATUS_RUNNING
 
-        form = validated_data.pop("form", None)
-        if form:
-            validated_data["document"] = Document.objects.create(
-                form=form, created_by_user=user.username, created_by_group=user.group
-            )
+        validated_data = domain_logic.StartCaseLogic.pre_start(validated_data, user)
 
-        if parent_work_item:
-            case = parent_work_item.case
-            while hasattr(case, "parent_work_item"):
-                case = case.parent_work_item.case
-            validated_data["family"] = case
+        case = super().create(validated_data)
 
-        instance = super().create(validated_data)
-
-        # Django doesn't save reverse one-to-one relationships automatically:
-        # https://code.djangoproject.com/ticket/18638
-        if parent_work_item:
-            parent_work_item.child_case = instance
-            parent_work_item.save()
-
-        workflow = instance.workflow
-        tasks = workflow.start_tasks.all()
-
-        work_items = bulk_create_work_items(tasks, instance, user)
-
-        self.send_event(events.created_case, case=instance)
-        for work_item in work_items:  # pragma: no cover
-            self.send_event(events.created_work_item, work_item=work_item)
-
-        return instance
+        return domain_logic.StartCaseLogic.post_start(
+            case, user, validated_data.get("parent_work_item")
+        )
 
     class Meta:
         model = models.Case
@@ -308,142 +220,81 @@ class CancelCaseSerializer(SendEventSerializerMixin, serializers.ModelSerializer
         fields = ("id",)
 
     def validate(self, data):
-        if self.instance.status != models.Case.STATUS_RUNNING:
-            raise exceptions.ValidationError("Only running cases can be canceled.")
+        try:
+            domain_logic.CancelCaseLogic.validate_for_cancel(self.instance)
+        except ValidationError as e:
+            raise exceptions.ValidationError(str(e))
 
-        user = self.context["request"].user
-        data["status"] = models.Case.STATUS_CANCELED
-        data["closed_at"] = timezone.now()
-        data["closed_by_user"] = user.username
-        data["closed_by_group"] = user.group
         return super().validate(data)
 
     @transaction.atomic
     def update(self, instance, validated_data):
-        instance = super().update(instance, validated_data)
         user = self.context["request"].user
 
-        work_items = instance.work_items.exclude(
-            status__in=[
-                models.WorkItem.STATUS_COMPLETED,
-                models.WorkItem.STATUS_CANCELED,
-            ]
+        super().update(
+            instance, domain_logic.CancelCaseLogic.pre_cancel(validated_data, user)
         )
 
-        for work_item in work_items:
-            work_item.status = models.WorkItem.STATUS_CANCELED
-            work_item.closed_at = timezone.now()
-            work_item.closed_by_user = user.username
-            work_item.closed_by_group = user.group
-            work_item.save()
+        domain_logic.CancelCaseLogic.post_cancel(instance, user)
 
-        # send events in separate loop in order to be sure all operations are finished
-        for work_item in work_items:
-            self.send_event(events.cancelled_work_item, work_item=work_item)
-
-        self.send_event(events.cancelled_case, case=instance)
         return instance
 
 
-class CompleteWorkItemSerializer(SendEventSerializerMixin, serializers.ModelSerializer):
+class CompleteWorkItemSerializer(serializers.ModelSerializer):
     id = serializers.GlobalIDField()
 
     def validate(self, data):
-        user = self.context["request"].user
-        validators.WorkItemValidator().validate(
-            status=self.instance.status,
-            child_case=self.instance.child_case,
-            task=self.instance.task,
-            case=self.instance.case,
-            document=self.instance.document,
-            info=self.context["info"],
-        )
-        data["status"] = models.WorkItem.STATUS_COMPLETED
-        data["closed_at"] = timezone.now()
-        data["closed_by_user"] = user.username
-        data["closed_by_group"] = user.group
+        try:
+            domain_logic.CompleteWorkItemLogic.validate_for_complete(
+                self.instance, self.context["request"].user
+            )
+        except ValidationError as e:
+            raise exceptions.ValidationError(str(e))
+
         return super().validate(data)
 
-    def _can_continue(self, instance, task):
-        # If a "multiple instance" task has running siblings, the task is not completed
-        if task.is_multiple_instance:
-            return not instance.case.work_items.filter(
-                task=task, status=models.WorkItem.STATUS_READY
-            ).exists()
-        return instance.case.work_items.filter(
-            task=task,
-            status__in=(
-                models.WorkItem.STATUS_COMPLETED,
-                models.WorkItem.STATUS_SKIPPED,
-            ),
-        ).exists()
-
     @transaction.atomic
-    def update(self, instance, validated_data):
-
-        instance = super().update(instance, validated_data)
+    def update(self, work_item, validated_data):
         user = self.context["request"].user
-        case = instance.case
 
-        if not self._can_continue(instance, instance.task):
-            return instance
-
-        flow = models.Flow.objects.filter(task_flows__task=instance.task_id).first()
-        flow_referenced_tasks = models.Task.objects.filter(task_flows__flow=flow)
-
-        all_complete = all(
-            self._can_continue(instance, task) for task in flow_referenced_tasks
+        validated_data = domain_logic.CompleteWorkItemLogic.pre_complete(
+            validated_data, user
         )
 
-        if flow and all_complete:
-            jexl = FlowJexl()
-            result = jexl.evaluate(flow.next)
-            if not isinstance(result, list):
-                result = [result]
+        work_item = super().update(work_item, validated_data)
+        work_item = domain_logic.CompleteWorkItemLogic.post_complete(work_item, user)
 
-            tasks = models.Task.objects.filter(pk__in=result)
-
-            work_items = bulk_create_work_items(tasks, case, user, instance)
-
-            for work_item in work_items:  # pragma: no cover
-                self.send_event(events.created_work_item, work_item=work_item)
-        else:
-            # no more tasks, mark case as complete
-            case.status = models.Case.STATUS_COMPLETED
-            case.closed_at = timezone.now()
-            case.closed_by_user = user.username
-            case.closed_by_group = user.group
-            case.save()
-            self.send_event(events.completed_case, case=case)
-
-        self.send_event(events.completed_work_item, work_item=instance)
-
-        return instance
+        return work_item
 
     class Meta:
         model = models.WorkItem
         fields = ("id",)
 
 
-class SkipWorkItemSerializer(CompleteWorkItemSerializer):
-    def validate(self, data):
-        if self.instance.status != models.WorkItem.STATUS_READY:
-            raise exceptions.ValidationError("Only READY work items can be skipped")
+class SkipWorkItemSerializer(serializers.ModelSerializer):
+    id = serializers.GlobalIDField()
 
-        user = self.context["request"].user
-        data["status"] = models.WorkItem.STATUS_SKIPPED
-        data["closed_at"] = timezone.now()
-        data["closed_by_user"] = user.username
-        data["closed_by_group"] = user.group
-        # We skip parent validation, as the work item is now "skipped",
-        # meaning no other conditions need apply
+    def validate(self, data):
+        try:
+            domain_logic.SkipWorkItemLogic.validate_for_skip(self.instance)
+        except ValidationError as e:
+            raise exceptions.ValidationError(str(e))
 
         return data
 
-    def update(self, instance, validated_data):
-        instance = super().update(instance, validated_data)
-        self.send_event(events.skipped_work_item, work_item=instance)
-        return instance
+    def update(self, work_item, validated_data):
+        user = self.context["request"].user
+
+        validated_data = domain_logic.SkipWorkItemLogic.pre_skip(validated_data, user)
+
+        work_item = super().update(work_item, validated_data)
+        work_item = domain_logic.SkipWorkItemLogic.post_skip(work_item, user)
+
+        return work_item
+
+    class Meta:
+        model = models.WorkItem
+        fields = ("id",)
 
 
 class SaveWorkItemSerializer(SendEventSerializerMixin, serializers.ModelSerializer):
@@ -519,12 +370,16 @@ class CreateWorkItemSerializer(SendEventSerializerMixin, serializers.ModelSerial
         data["status"] = models.WorkItem.STATUS_READY
 
         if "controlling_groups" not in data:
-            controlling_groups = get_jexl_groups(task.control_groups, case, user.group)
+            controlling_groups = utils.get_jexl_groups(
+                task.control_groups, case, user.group
+            )
             if controlling_groups is not None:
                 data["controlling_groups"] = controlling_groups
 
         if "addressed_groups" not in data:
-            addressed_groups = get_jexl_groups(task.address_groups, case, user.group)
+            addressed_groups = utils.get_jexl_groups(
+                task.address_groups, case, user.group
+            )
             if addressed_groups is not None:
                 data["addressed_groups"] = addressed_groups
 
