@@ -6,7 +6,7 @@ from graphene.utils.str_converters import to_const
 from ...caluma_core.relay import extract_global_id
 from ...caluma_form.models import Question
 from ...caluma_user.models import BaseUser
-from .. import models
+from .. import api, models
 
 
 def test_query_all_work_items_filter_status(db, work_item_factory, schema_executor):
@@ -27,7 +27,7 @@ def test_query_all_work_items_filter_status(db, work_item_factory, schema_execut
     """
 
     result = schema_executor(
-        query, variables={"status": to_const(models.WorkItem.STATUS_READY)}
+        query, variable_values={"status": to_const(models.WorkItem.STATUS_READY)}
     )
 
     assert not result.errors
@@ -69,7 +69,7 @@ def test_query_all_work_items_filter_groups(
             }
         """
 
-    result = schema_executor(query, variables={"groups": ["B", "C"]})
+    result = schema_executor(query, variable_values={"groups": ["B", "C"]})
 
     assert not result.errors
     assert len(result.data["allWorkItems"]["edges"]) == 1
@@ -78,7 +78,7 @@ def test_query_all_work_items_filter_groups(
         "B",
     ]
 
-    result = schema_executor(query, variables={"groups": ["C", "D"]})
+    result = schema_executor(query, variable_values={"groups": ["C", "D"]})
 
     assert not result.errors
     assert len(result.data["allWorkItems"]["edges"]) == 0
@@ -114,7 +114,7 @@ def test_complete_work_item_last(
     """
 
     inp = {"input": {"id": work_item.pk}}
-    result = admin_schema_executor(query, variables=inp)
+    result = admin_schema_executor(query, variable_values=inp)
 
     assert not bool(result.errors) == success
     if success:
@@ -177,7 +177,7 @@ def test_complete_workflow_form_work_item(
     """
 
     inp = {"input": {"id": work_item.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert not bool(result.errors) == success
     if success:
@@ -223,7 +223,7 @@ def test_complete_task_form_work_item(
     """
 
     inp = {"input": {"id": work_item.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert not bool(result.errors) == success
     if success:
@@ -257,7 +257,7 @@ def test_complete_multiple_instance_task_form_work_item(
     """
 
     inp = {"input": {"id": work_item_1.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert not bool(result.errors)
     assert result.data["completeWorkItem"]["workItem"]["status"] == to_const(
@@ -268,7 +268,7 @@ def test_complete_multiple_instance_task_form_work_item(
     )
 
     inp = {"input": {"id": work_item_2.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert not bool(result.errors)
     assert result.data["completeWorkItem"]["workItem"]["status"] == to_const(
@@ -302,7 +302,7 @@ def test_complete_multiple_instance_task_form_work_item_next(
     task_next = task_factory(
         type=models.Task.TYPE_SIMPLE, form=None, address_groups='["group-name"]|groups'
     )
-    task_flow = task_flow_factory(task=task)
+    task_flow = task_flow_factory(task=task, workflow=work_item.case.workflow)
     task_flow.flow.next = f"'{task_next.slug}'|task"
     task_flow.flow.save()
 
@@ -330,7 +330,7 @@ def test_complete_multiple_instance_task_form_work_item_next(
     """
 
     inp = {"input": {"id": work_item.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert not bool(result.errors)
     snapshot.assert_match(result.data)
@@ -419,7 +419,7 @@ def test_complete_work_item_with_next(
     """
 
     inp = {"input": {"id": work_item.pk}}
-    result = schema_executor(query, variables=inp, info=info)
+    result = schema_executor(query, variable_values=inp, info=info)
 
     assert not result.errors
     snapshot.assert_match(result.data)
@@ -469,7 +469,7 @@ def test_complete_work_item_with_next_multiple_tasks(
     """
 
     inp = {"input": {"id": work_item.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert not result.errors
     assert case.work_items.count() == 3
@@ -524,7 +524,7 @@ def test_complete_work_item_with_next_multiple_instance_task(
     """
 
     inp = {"input": {"id": work_item.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert not result.errors
     assert case.work_items.filter(status=models.WorkItem.STATUS_READY).count() == 3
@@ -577,7 +577,7 @@ def test_complete_work_item_with_merge(
         }
     """
     inp = {"input": {"id": work_item_1.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
     assert not result.errors
 
     # one parallel work item is left, no new one created as both preceding
@@ -587,7 +587,7 @@ def test_complete_work_item_with_merge(
 
     # complete second work item
     inp = {"input": {"id": work_item_2.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
     assert not result.errors
 
     # new work item is created of merge task
@@ -644,7 +644,7 @@ def test_save_work_item(
             "description": work_item_description,
         }
     }
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert not result.errors
     work_item.refresh_from_db()
@@ -755,7 +755,7 @@ def test_create_work_item(
         inp["input"]["controllingGroups"] = []
         inp["input"]["addressedGroups"] = []
 
-    result = schema_executor(query, variables=inp, info=info)
+    result = schema_executor(query, variable_values=inp, info=info)
 
     assert not bool(result.errors) == success
     if success:
@@ -810,7 +810,7 @@ def test_filter_document_has_answer(
 
         result = schema_executor(
             query,
-            variables={
+            variable_values={
                 "has_answer": [{"question": answer.question_id, "value": "foo"}]
             },
         )
@@ -873,7 +873,7 @@ def test_query_all_work_items_filter_case_meta_value(
     if lookup_expr:
         variables["lookup"] = lookup_expr
 
-    result = schema_executor(query, variables={"case_meta_value": [variables]})
+    result = schema_executor(query, variable_values={"case_meta_value": [variables]})
 
     assert not result.errors
     assert len(result.data["allWorkItems"]["edges"]) == len_results
@@ -913,7 +913,7 @@ def test_skip_task_form_work_item(
     """
 
     inp = {"input": {"id": work_item.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     # when skipping, both valid and invalid forms don't matter (contrary
     # to completion, where it DOES matter)
@@ -964,7 +964,7 @@ def test_skip_multiple_instance_task_form_work_item(
     """
 
     inp = {"input": {"id": work_item_1.pk}}
-    result = schema_executor(query, variables=inp)
+    result = schema_executor(query, variable_values=inp)
 
     assert bool(result.errors) != success
 
@@ -981,7 +981,7 @@ def test_skip_multiple_instance_task_form_work_item(
         )
 
         inp = {"input": {"id": work_item_2.pk}}
-        result = schema_executor(query, variables=inp)
+        result = schema_executor(query, variable_values=inp)
 
         assert not bool(result.errors)
         assert result.data["skipWorkItem"]["workItem"]["status"] == to_const(
@@ -990,3 +990,121 @@ def test_skip_multiple_instance_task_form_work_item(
         assert result.data["skipWorkItem"]["workItem"]["case"]["status"] == to_const(
             models.Case.STATUS_COMPLETED
         )
+
+
+@pytest.mark.parametrize("task__type,task__form", [(models.Task.TYPE_SIMPLE, None)])
+@pytest.mark.parametrize(
+    "work_item__status,case__status",
+    [(models.WorkItem.STATUS_READY, models.Case.STATUS_COMPLETED)],
+)
+def test_complete_work_item_last_api(db, work_item, admin_user):
+    api.complete_work_item(work_item, admin_user)
+
+    work_item.refresh_from_db()
+
+    assert work_item.status == models.WorkItem.STATUS_COMPLETED
+    assert work_item.case.status == models.Case.STATUS_COMPLETED
+
+
+@pytest.mark.parametrize("task__type,task__form", [(models.Task.TYPE_SIMPLE, None)])
+@pytest.mark.parametrize(
+    "work_item__status,case__status",
+    [(models.WorkItem.STATUS_READY, models.Case.STATUS_COMPLETED)],
+)
+def test_skip_work_item_last_api(db, work_item, admin_user):
+    api.skip_work_item(work_item, admin_user)
+
+    work_item.refresh_from_db()
+
+    assert work_item.status == models.WorkItem.STATUS_SKIPPED
+    assert work_item.case.status == models.Case.STATUS_COMPLETED
+
+
+@pytest.mark.parametrize(
+    "work_item__status,work_item__child_case,task__type",
+    [(models.WorkItem.STATUS_COMPLETED, None, models.Task.TYPE_SIMPLE)],
+)
+def test_complete_work_item_parallel(
+    db,
+    case,
+    work_item,
+    work_item_factory,
+    task,
+    task_factory,
+    flow_factory,
+    task_flow_factory,
+    workflow,
+    schema_executor,
+    admin_user,
+):
+    # create two work items which can be processed in parallel
+    task_1, task_2 = task_factory.create_batch(2, type=models.Task.TYPE_SIMPLE)
+    flow = flow_factory(next=f"['{task_1.slug}','{task_2.slug}']|tasks")
+    task_flow_factory(task=work_item.task, workflow=workflow, flow=flow)
+    work_item_factory(
+        task=task_1, status=models.WorkItem.STATUS_READY, child_case=None, case=case
+    )
+    work_item_factory(
+        task=task_2, status=models.WorkItem.STATUS_READY, child_case=None, case=case
+    )
+
+    ready_work_items = case.work_items.filter(status=models.WorkItem.STATUS_READY)
+
+    for i, ready_work_item in enumerate(ready_work_items):
+        api.complete_work_item(ready_work_item, admin_user)
+
+        ready_work_item.refresh_from_db()
+        case.refresh_from_db()
+
+        assert ready_work_item.status == models.WorkItem.STATUS_COMPLETED
+
+        # if we have multiple parallel running work items without a flow (end
+        # of the workflow), the case should only be completed when all parallel
+        # work items are completed
+        if i + 1 == len(ready_work_items):
+            assert case.status == models.Case.STATUS_COMPLETED
+        else:
+            assert case.status == models.Case.STATUS_RUNNING
+
+
+def test_complete_work_item_same_task_multiple_workflows(
+    db,
+    case_factory,
+    work_item_factory,
+    task_factory,
+    flow_factory,
+    task_flow_factory,
+    workflow_factory,
+    schema_executor,
+    admin_user,
+):
+    workflow_1, workflow_2 = workflow_factory.create_batch(2)
+    # create two work items which can be processed in parallel
+    task_1, task_2 = task_factory.create_batch(2, type=models.Task.TYPE_SIMPLE)
+
+    flow = flow_factory(next=f"'{task_2.slug}'|task")
+
+    # workflow 1 consists out of 2 tasks, workflow_2 just out of one
+    task_flow_factory(task=task_1, workflow=workflow_1, flow=flow)
+
+    case_1 = case_factory(workflow=workflow_1)
+    case_2 = case_factory(workflow=workflow_2)
+
+    work_item_1 = work_item_factory(
+        task=task_1, status=models.WorkItem.STATUS_READY, child_case=None, case=case_1
+    )
+    work_item_2 = work_item_factory(
+        task=task_1, status=models.WorkItem.STATUS_READY, child_case=None, case=case_2
+    )
+
+    api.complete_work_item(work_item_1, admin_user)
+    api.complete_work_item(work_item_2, admin_user)
+
+    work_item_1.refresh_from_db()
+    work_item_2.refresh_from_db()
+
+    case_1.refresh_from_db()
+    case_2.refresh_from_db()
+
+    assert case_1.status == models.Case.STATUS_RUNNING
+    assert case_2.status == models.Case.STATUS_COMPLETED
